@@ -19,7 +19,7 @@
 
 #include "screenshooter-capture.h"
 
-
+#define BACKGROUND_TRANSPARENCY 0.4
 
 /* Rubberband data for composited environment */
 typedef struct
@@ -30,8 +30,8 @@ typedef struct
   gint y;
   gint x_root;
   gint y_root;
-  GdkRectangle rectangle;
-  GdkRectangle rectangle_root;
+  cairo_rectangle_int_t rectangle;
+  cairo_rectangle_int_t rectangle_root;
 } RubberBandData;
 
 /* For non-composited environments */
@@ -39,10 +39,9 @@ typedef struct
 {
   gboolean pressed;
   gboolean cancelled;
-  GdkRectangle rectangle;
+  cairo_rectangle_int_t rectangle;
   gint x1, y1; /* holds the position where the mouse was pressed */
-  GdkGC *gc;
-  GdkWindow *root_window;
+  GC *context;
 } RbData;
 
 
@@ -67,12 +66,12 @@ static GdkPixbuf       *get_window_screenshot               (GdkWindow      *win
 static GdkFilterReturn  region_filter_func                  (GdkXEvent      *xevent,
                                                              GdkEvent       *event,
                                                              RbData         *rbdata);
-static GdkPixbuf       *get_rectangle_screenshot            (void);
+static GdkPixbuf       *get_rectangle_screenshot            (gint delay);
 static gboolean         cb_key_pressed                      (GtkWidget      *widget,
                                                              GdkEventKey    *event,
                                                              gboolean       *cancelled);
-static gboolean         cb_expose                           (GtkWidget      *widget,
-                                                             GdkEventExpose *event,
+static gboolean         cb_draw                             (GtkWidget      *widget,
+                                                             cairo_t        *cr,
                                                              RubberBandData *rbdata);
 static gboolean         cb_button_pressed                   (GtkWidget      *widget,
                                                              GdkEventButton *event,
@@ -83,7 +82,7 @@ static gboolean         cb_button_released                  (GtkWidget      *wid
 static gboolean         cb_motion_notify                    (GtkWidget      *widget,
                                                              GdkEventMotion *event,
                                                              RubberBandData *rbdata);
-static GdkPixbuf       *get_rectangle_screenshot_composited (void);
+static GdkPixbuf       *get_rectangle_screenshot_composited (gint delay);
 
 
 
@@ -111,7 +110,7 @@ static GdkWindow
       *needs_unref = FALSE;
       *border = FALSE;
     }
-  else if (G_UNLIKELY (GDK_WINDOW_DESTROYED (window)))
+  else if (G_UNLIKELY (gdk_window_is_destroyed (window)))
     {
       TRACE ("The active window is destroyed, fallback to the root window.");
 
@@ -157,7 +156,7 @@ find_wm_window (Window xid)
 
   do
     {
-      if (XQueryTree (GDK_DISPLAY (), xid, &root,
+      if (XQueryTree (gdk_x11_get_default_xdisplay (), xid, &root,
                       &parent, &children, &nchildren) == 0)
         {
           g_warning ("Couldn't find window manager window");
@@ -188,6 +187,8 @@ static GdkPixbuf *get_cursor_pixbuf (GdkDisplay *display,
 {
   GdkCursor *cursor = NULL;
   GdkPixbuf *cursor_pixbuf = NULL;
+  GdkDevice *pointer = NULL;
+  GdkSeat   *seat = NULL;
 
 #ifdef HAVE_XFIXES
   XFixesCursorImage *cursor_image = NULL;
@@ -256,13 +257,16 @@ fallback:
     return NULL;
 
   TRACE ("Get the coordinates of the cursor");
-  gdk_window_get_pointer (root, cursorx, cursory, NULL);
+  
+  seat = gdk_display_get_default_seat (gdk_display_get_default ());
+  pointer = gdk_seat_get_pointer (seat);
+  gdk_window_get_device_position (root, pointer, cursorx, cursory, NULL);
 
   TRACE ("Get the cursor hotspot");
   sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "x_hot"), "%d", xhot);
   sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "y_hot"), "%d", yhot);
 
-  gdk_cursor_unref (cursor);
+  g_object_unref (cursor);
 
   return cursor_pixbuf;
 }
@@ -288,11 +292,13 @@ static GdkPixbuf
 
   if (border)
     {
-      Window xwindow = GDK_WINDOW_XWINDOW (window);
-      window = gdk_window_foreign_new (find_wm_window (xwindow));
+	  Window xwindow = GDK_WINDOW_XID (window);
+      window = gdk_x11_window_foreign_new_for_display (gdk_window_get_display (window),
+    		                                           find_wm_window (xwindow));
     }
 
-  gdk_drawable_get_size (window, &rectangle.width, &rectangle.height);
+  rectangle.width = gdk_window_get_width (window);
+  rectangle.height = gdk_window_get_height (window);
   gdk_window_get_origin (window, &rectangle.x, &rectangle.y);
 
   /* Don't grab thing offscreen. */
@@ -327,9 +333,7 @@ static GdkPixbuf
 
   TRACE ("Grab the screenshot");
 
-  screenshot = gdk_pixbuf_get_from_drawable (NULL, root, NULL,
-                                             x_orig, y_orig, 0, 0,
-                                             width, height);
+  screenshot = gdk_pixbuf_get_from_window (root, x_orig, y_orig, width, height);
 
   /* Code adapted from gnome-screenshot:
    * Copyright (C) 2001-2006  Jonathan Blandford <jrb@alum.mit.edu>
@@ -342,8 +346,8 @@ static GdkPixbuf
       GdkPixbuf *tmp;
       int rectangle_count, rectangle_order, i;
 
-      rectangles = XShapeGetRectangles (GDK_DISPLAY (),
-                                        GDK_WINDOW_XWINDOW (window),
+      rectangles = XShapeGetRectangles (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
+                                        GDK_WINDOW_XID (window),
                                         ShapeBounding,
                                         &rectangle_count,
                                         &rectangle_order);
@@ -489,7 +493,7 @@ static gboolean cb_key_pressed (GtkWidget   *widget,
                                 GdkEventKey *event,
                                 gboolean    *cancelled)
 {
-  if (event->keyval == GDK_Escape)
+  if (event->keyval == GDK_KEY_Escape)
     {
       gtk_widget_hide (widget);
       *cancelled = TRUE;
@@ -501,35 +505,40 @@ static gboolean cb_key_pressed (GtkWidget   *widget,
 
 
 
-static gboolean cb_expose (GtkWidget *widget,
-                           GdkEventExpose *event,
-                           RubberBandData *rbdata)
+static gboolean cb_draw (GtkWidget *widget,
+                         cairo_t *cr,
+                         RubberBandData *rbdata)
 {
-  GdkRectangle *rects = NULL;
+  cairo_rectangle_t *rects = NULL;
+  cairo_rectangle_list_t *list = NULL;
   gint n_rects = 0, i;
 
-  TRACE ("Expose event received.");
+  TRACE ("Draw event received.");
 
-  gdk_region_get_rectangles (event->region, &rects, &n_rects);
+  list = cairo_copy_clip_rectangle_list (cr);
+  n_rects = list->num_rectangles;
+  rects = list->rectangles;
 
   if (rbdata->rubber_banding)
     {
-      GdkRectangle intersect;
-      cairo_t *cr;
+      cairo_rectangle_int_t intersect;
+      GdkRectangle rect;
 
-      cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
       cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
       for (i = 0; i < n_rects; ++i)
         {
           /* Restore the transparent background */
-          cairo_set_source_rgba (cr, 0, 0, 0, 0.8);
-          gdk_cairo_rectangle (cr, &rects[i]);
+          cairo_set_source_rgba (cr, 0, 0, 0, BACKGROUND_TRANSPARENCY);
+          cairo_rectangle(cr, rects[i].x, rects[i].y, rects[i].width, rects[i].height);
           cairo_fill (cr);
 
-          if (!gdk_rectangle_intersect (&rects[i],
-                                        &rbdata->rectangle,
-                                        &intersect))
+          rect.x = (rects[i].x);
+          rect.y =  (rects[i].y);
+          rect.width = (rects[i].width);
+          rect.height = (rects[i].height);
+
+          if (!gdk_rectangle_intersect (&rect, &rbdata->rectangle, &intersect))
             {
               continue;
             }
@@ -539,28 +548,22 @@ static gboolean cb_expose (GtkWidget *widget,
           gdk_cairo_rectangle (cr, &intersect);
           cairo_fill (cr);
         }
-
-      cairo_destroy (cr);
     }
   else
     {
-      cairo_t *cr;
-
       /* Draw the transparent background */
-      cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-      cairo_set_source_rgba (cr, 0, 0, 0, 0.8);
+      cairo_set_source_rgba (cr, 0, 0, 0, BACKGROUND_TRANSPARENCY);
       cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
       for (i = 0; i < n_rects; ++i)
         {
-            gdk_cairo_rectangle (cr, &rects[i]);
-            cairo_fill (cr);
+          cairo_rectangle(cr, rects[i].x, rects[i].y, rects[i].width, rects[i].height);
+          cairo_fill (cr);
         }
 
-      cairo_destroy (cr);
     }
 
-  g_free (rects);
+  cairo_rectangle_list_destroy (list);
 
   return FALSE;
 }
@@ -615,9 +618,9 @@ static gboolean cb_motion_notify (GtkWidget *widget,
 {
   if (rbdata->left_pressed)
     {
-      GdkRectangle *new_rect, *new_rect_root;
-      GdkRectangle old_rect, intersect;
-      GdkRegion *region;
+      cairo_rectangle_int_t *new_rect, *new_rect_root;
+      cairo_rectangle_int_t old_rect, intersect;
+      cairo_region_t *region;
 
       TRACE ("Mouse is moving with left button pressed");
 
@@ -652,28 +655,28 @@ static gboolean cb_motion_notify (GtkWidget *widget,
       new_rect_root->width = ABS (rbdata->x_root - event->x_root) + 1;
       new_rect_root->height = ABS (rbdata->y_root - event->y_root) +1;
 
-      region = gdk_region_rectangle (&old_rect);
-      gdk_region_union_with_rect (region, new_rect);
+      region = cairo_region_create_rectangle (&old_rect);
+      cairo_region_union_rectangle (region, new_rect);
 
       /* Try to be smart: don't send the expose event for regions which
        * have already been painted */
       if (gdk_rectangle_intersect (&old_rect, new_rect, &intersect)
           && intersect.width > 2 && intersect.height > 2)
         {
-          GdkRegion *region_intersect;
+          cairo_region_t *region_intersect;
 
           intersect.x += 1;
           intersect.width -= 2;
           intersect.y += 1;
           intersect.height -= 2;
 
-          region_intersect = gdk_region_rectangle(&intersect);
-          gdk_region_subtract(region, region_intersect);
-          gdk_region_destroy(region_intersect);
+          region_intersect = cairo_region_create_rectangle(&intersect);
+          cairo_region_subtract(region, region_intersect);
+          cairo_region_destroy(region_intersect);
         }
 
-      gdk_window_invalidate_region (widget->window, region, TRUE);
-      gdk_region_destroy (region);
+      gdk_window_invalidate_region (gtk_widget_get_window (widget), region, TRUE);
+      cairo_region_destroy (region);
 
       return TRUE;
     }
@@ -683,14 +686,17 @@ static gboolean cb_motion_notify (GtkWidget *widget,
 
 
 static GdkPixbuf
-*get_rectangle_screenshot_composited (void)
+*get_rectangle_screenshot_composited (gint delay)
 {
   GtkWidget *window;
   RubberBandData rbdata;
   gboolean cancelled = FALSE;
   GdkPixbuf *screenshot;
   GdkWindow *root;
-  GdkCursor *xhair_cursor = gdk_cursor_new (GDK_CROSSHAIR);
+  GdkDevice *pointer, *keyboard;
+  GdkSeat   *seat;
+  GdkCursor *xhair_cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
+                                                        GDK_CROSSHAIR);
 
   /* Initialize the rubber band data */
   rbdata.left_pressed = FALSE;
@@ -703,7 +709,6 @@ static GdkPixbuf
   gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
   gtk_window_set_deletable (GTK_WINDOW (window), FALSE);
   gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
-  gtk_dialog_set_has_separator (GTK_DIALOG (window), FALSE);
   gtk_widget_set_app_paintable (window, TRUE);
   gtk_widget_add_events (window,
                          GDK_BUTTON_RELEASE_MASK |
@@ -711,14 +716,13 @@ static GdkPixbuf
                          GDK_EXPOSURE_MASK |
                          GDK_POINTER_MOTION_MASK |
                          GDK_KEY_PRESS_MASK);
-  gtk_widget_set_colormap (window,
-                           gdk_screen_get_rgba_colormap (gdk_screen_get_default ()));
+  gtk_widget_set_visual (window, gdk_screen_get_rgba_visual (gdk_screen_get_default ()));
 
   /* Connect to the interesting signals */
   g_signal_connect (window, "key-press-event",
                     G_CALLBACK (cb_key_pressed), &cancelled);
-  g_signal_connect (window, "expose-event",
-                    G_CALLBACK (cb_expose), &rbdata);
+  g_signal_connect (window, "draw",
+                    G_CALLBACK (cb_draw), &rbdata);
   g_signal_connect (window, "button-press-event",
                     G_CALLBACK (cb_button_pressed), &rbdata);
   g_signal_connect (window, "button-release-event",
@@ -729,25 +733,39 @@ static GdkPixbuf
   /* This window is not managed by the window manager, we have to set everything
    * ourselves */
   gtk_widget_realize (window);
-  gdk_window_set_cursor (window->window, xhair_cursor);
-  gdk_window_set_override_redirect (window->window, TRUE);
+  gdk_window_set_cursor (gtk_widget_get_window (window), xhair_cursor);
+  gdk_window_set_override_redirect (gtk_widget_get_window (window), TRUE);
   gtk_widget_set_size_request (window,
                                gdk_screen_get_width (gdk_screen_get_default ()),
                                gdk_screen_get_height (gdk_screen_get_default ()));
-  gdk_window_raise (window->window);
+  gdk_window_raise (gtk_widget_get_window (window));
   gtk_widget_show_now (window);
   gtk_widget_grab_focus (window);
   gdk_flush ();
 
   /* Grab the mouse and the keyboard to prevent any interaction with other
    * applications */
-  gdk_keyboard_grab (window->window, FALSE, GDK_CURRENT_TIME);
-  gdk_pointer_grab (window->window, TRUE, 0, NULL,
-                    NULL, GDK_CURRENT_TIME);
+  seat = gdk_display_get_default_seat (gdk_display_get_default ());
+  pointer = gdk_seat_get_pointer (seat);
+  keyboard = gdk_seat_get_keyboard (seat);
+
+  gdk_device_grab (keyboard, gtk_widget_get_window (window),
+                  GDK_OWNERSHIP_NONE, FALSE,
+                  GDK_KEY_PRESS_MASK |
+                  GDK_KEY_RELEASE_MASK,
+                  NULL, GDK_CURRENT_TIME);
+
+  gdk_device_grab (pointer, gtk_widget_get_window (window),
+                   GDK_OWNERSHIP_NONE, FALSE,
+                   GDK_POINTER_MOTION_MASK |
+                   GDK_BUTTON_PRESS_MASK | 
+                   GDK_BUTTON_RELEASE_MASK,
+                   NULL, GDK_CURRENT_TIME);
 
   gtk_dialog_run (GTK_DIALOG (window));
   gtk_widget_destroy (window);
-  gdk_cursor_unref (xhair_cursor);
+  g_object_unref (xhair_cursor);
+  gdk_flush();
 
   if (cancelled)
     return NULL;
@@ -760,16 +778,18 @@ static GdkPixbuf
 
   /* Grab the screenshot on the main window */
   root = gdk_get_default_root_window ();
-  gdk_pixbuf_get_from_drawable (screenshot, root, NULL,
-                                rbdata.rectangle_root.x,
-                                rbdata.rectangle_root.y,
-                                0, 0,
-                                rbdata.rectangle.width,
-                                rbdata.rectangle.height);
+
+  sleep(delay);
+
+  screenshot = gdk_pixbuf_get_from_window (root,
+                                           rbdata.rectangle_root.x,
+                                           rbdata.rectangle_root.y,
+                                           rbdata.rectangle.width,
+                                           rbdata.rectangle.height);
 
   /* Ungrab the mouse and the keyboard */
-  gdk_pointer_ungrab (GDK_CURRENT_TIME);
-  gdk_keyboard_ungrab (GDK_CURRENT_TIME);
+  gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+  gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
   gdk_flush ();
 
   return screenshot;
@@ -782,15 +802,26 @@ region_filter_func (GdkXEvent *xevent, GdkEvent *event, RbData *rbdata)
 {
   XEvent *x_event = (XEvent *) xevent;
   gint x2 = 0, y2 = 0;
+  XIDeviceEvent *device_event;
+  Display *display;
+  Window root_window;
 
-  switch (x_event->type)
+  display = gdk_x11_get_default_xdisplay ();
+  root_window = gdk_x11_get_default_root_xwindow ();
+
+  if (x_event->type != GenericEvent)
+    return GDK_FILTER_CONTINUE;
+
+  switch (x_event->xgeneric.evtype)
     {
       /* Start dragging the rectangle out */
-      case ButtonPress:
+      case XI_ButtonPress:
         TRACE ("Start dragging the rectangle");
 
-        rbdata->rectangle.x = rbdata->x1 = x_event->xkey.x_root;
-        rbdata->rectangle.y = rbdata->y1 = x_event->xkey.y_root;
+        device_event = (XIDeviceEvent*) x_event->xcookie.data;
+
+        rbdata->rectangle.x = rbdata->x1 = device_event->root_x;
+        rbdata->rectangle.y = rbdata->y1 = device_event->root_y;
         rbdata->rectangle.width = 0;
         rbdata->rectangle.height = 0;
         rbdata->pressed = TRUE;
@@ -799,30 +830,27 @@ region_filter_func (GdkXEvent *xevent, GdkEvent *event, RbData *rbdata)
       break;
 
       /* Finish dragging the rectangle out */
-      case ButtonRelease:
+      case XI_ButtonRelease:
         if (rbdata->pressed)
           {
-            if (rbdata->rectangle.width > 0 &&
-                rbdata->rectangle.height > 0)
+            if (rbdata->rectangle.width > 0 && rbdata->rectangle.height > 0)
               {
                 /* Remove the rectangle drawn previously */
-
                 TRACE ("Remove the rectangle drawn previously");
 
-                gdk_draw_rectangle (rbdata->root_window,
-                                    rbdata->gc,
-                                    FALSE,
-                                    rbdata->rectangle.x,
-                                    rbdata->rectangle.y,
-                                    rbdata->rectangle.width,
-                                    rbdata->rectangle.height);
+                XDrawRectangle (display,
+                                root_window,
+                                *rbdata->context,
+                                rbdata->rectangle.x,
+                                rbdata->rectangle.y,
+                                (unsigned int) rbdata->rectangle.width-1,
+                                (unsigned int) rbdata->rectangle.height-1);
 
                 gtk_main_quit ();
               }
             else
               {
                 /* The user has not dragged the mouse, start again */
-
                 TRACE ("Mouse was not dragged, start again");
 
                 rbdata->pressed = FALSE;
@@ -832,28 +860,28 @@ region_filter_func (GdkXEvent *xevent, GdkEvent *event, RbData *rbdata)
       break;
 
       /* The user is moving the mouse */
-      case MotionNotify:
+      case XI_Motion:
         if (rbdata->pressed)
           {
             TRACE ("Mouse is moving");
 
-            if (rbdata->rectangle.width > 0 &&
-                rbdata->rectangle.height > 0)
+            if (rbdata->rectangle.width > 0 && rbdata->rectangle.height > 0)
               {
                 /* Remove the rectangle drawn previously */
-
                 TRACE ("Remove the rectangle drawn previously");
-                gdk_draw_rectangle (rbdata->root_window,
-                                    rbdata->gc,
-                                    FALSE,
-                                    rbdata->rectangle.x,
-                                    rbdata->rectangle.y,
-                                    rbdata->rectangle.width,
-                                    rbdata->rectangle.height);
+
+                XDrawRectangle (display,
+                                root_window,
+                                *rbdata->context,
+                                rbdata->rectangle.x,
+                                rbdata->rectangle.y,
+                                (unsigned int) rbdata->rectangle.width-1,
+                                (unsigned int) rbdata->rectangle.height-1);
               }
 
-            x2 = x_event->xkey.x_root;
-            y2 = x_event->xkey.y_root;
+            device_event = (XIDeviceEvent*) x_event->xcookie.data;
+            x2 = device_event->root_x;
+            y2 = device_event->root_y;
 
             rbdata->rectangle.x = MIN (rbdata->x1, x2);
             rbdata->rectangle.y = MIN (rbdata->y1, y2);
@@ -862,40 +890,41 @@ region_filter_func (GdkXEvent *xevent, GdkEvent *event, RbData *rbdata)
 
             /* Draw  the rectangle as the user drags the mouse */
             TRACE ("Draw the new rectangle");
-            if (rbdata->rectangle.width > 0 &&
-                rbdata->rectangle.height > 0)
-              gdk_draw_rectangle (rbdata->root_window,
-                                  rbdata->gc,
-                                  FALSE,
-                                  rbdata->rectangle.x,
-                                  rbdata->rectangle.y,
-                                  rbdata->rectangle.width,
-                                  rbdata->rectangle.height);
+            if (rbdata->rectangle.width > 0 && rbdata->rectangle.height > 0)
+              {
+                XDrawRectangle (display,
+                                root_window,
+                                *rbdata->context,
+                                rbdata->rectangle.x,
+                                rbdata->rectangle.y,
+                                (unsigned int) rbdata->rectangle.width-1,
+                                (unsigned int) rbdata->rectangle.height-1);
+              }
           }
         return GDK_FILTER_REMOVE;
         break;
 
-      case KeyPress:
-        if (x_event->xkey.keycode == XKeysymToKeycode (gdk_display, XK_Escape))
+      case XI_KeyPress:
+        device_event = (XIDeviceEvent*) x_event->xcookie.data;
+
+        if (device_event->detail == XKeysymToKeycode (gdk_x11_get_default_xdisplay(), XK_Escape))
           {
             TRACE ("Escape key was pressed, cancel the screenshot.");
 
             if (rbdata->pressed)
               {
-                if (rbdata->rectangle.width > 0 &&
-                    rbdata->rectangle.height > 0)
+                if (rbdata->rectangle.width > 0 && rbdata->rectangle.height > 0)
                   {
                     /* Remove the rectangle drawn previously */
-
                     TRACE ("Remove the rectangle drawn previously");
 
-                    gdk_draw_rectangle (rbdata->root_window,
-                                        rbdata->gc,
-                                        FALSE,
-                                        rbdata->rectangle.x,
-                                        rbdata->rectangle.y,
-                                        rbdata->rectangle.width,
-                                        rbdata->rectangle.height);
+                    XDrawRectangle (display,
+                                   root_window,
+                                   *rbdata->context,
+                                   rbdata->rectangle.x,
+                                   rbdata->rectangle.y,
+                                   (unsigned int) rbdata->rectangle.width-1,
+                                   (unsigned int) rbdata->rectangle.height-1);
                   }
               }
 
@@ -915,65 +944,75 @@ region_filter_func (GdkXEvent *xevent, GdkEvent *event, RbData *rbdata)
 
 
 static GdkPixbuf
-*get_rectangle_screenshot (void)
+*get_rectangle_screenshot (gint delay)
 {
   GdkPixbuf *screenshot = NULL;
   GdkWindow *root_window;
 
-  GdkGCValues gc_values;
-  GdkGC *gc;
-
-  GdkGCValuesMask values_mask =
-    GDK_GC_FUNCTION | GDK_GC_FILL | GDK_GC_CLIP_MASK |
-    GDK_GC_SUBWINDOW | GDK_GC_CLIP_X_ORIGIN | GDK_GC_CLIP_Y_ORIGIN |
-    GDK_GC_EXPOSURES | GDK_GC_LINE_WIDTH | GDK_GC_LINE_STYLE |
-    GDK_GC_CAP_STYLE | GDK_GC_JOIN_STYLE;
-
-  GdkColor gc_white = {0, 65535, 65535, 65535};
-  GdkColor gc_black = {0, 0, 0, 0};
-
-  GdkEventMask mask =
-    GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK |
-    GDK_BUTTON_RELEASE_MASK;
-  GdkCursor *xhair_cursor = gdk_cursor_new (GDK_CROSSHAIR);
+  XGCValues gc_values;
+  GC gc;
 
+  Display *display;
+  gint screen;
   RbData rbdata;
+  GdkCursor *xhair_cursor;
+  GdkDevice *pointer, *keyboard;
+  GdkSeat   *seat;
+  long value_mask;
 
   /* Get root window */
   TRACE ("Get the root window");
   root_window = gdk_get_default_root_window ();
+  display = gdk_x11_get_default_xdisplay ();
+  screen = gdk_x11_get_default_screen ();
 
   /*Set up graphics context for a XOR rectangle that will be drawn as
    * the user drags the mouse */
   TRACE ("Initialize the graphics context");
 
-  gc_values.function           = GDK_XOR;
-  gc_values.line_width         = 2;
-  gc_values.line_style         = GDK_LINE_ON_OFF_DASH;
-  gc_values.fill               = GDK_SOLID;
-  gc_values.cap_style          = GDK_CAP_BUTT;
-  gc_values.join_style         = GDK_JOIN_MITER;
+  gc_values.function = GXxor;
+  gc_values.line_width = 2;
+  gc_values.line_style = LineOnOffDash;
+  gc_values.fill_style = FillSolid;
   gc_values.graphics_exposures = FALSE;
-  gc_values.clip_x_origin      = 0;
-  gc_values.clip_y_origin      = 0;
-  gc_values.clip_mask          = None;
-  gc_values.subwindow_mode     = GDK_INCLUDE_INFERIORS;
+  gc_values.subwindow_mode = IncludeInferiors;
+  gc_values.background = XBlackPixel (display, screen);
+  gc_values.foreground = XWhitePixel (display, screen);
 
-  gc = gdk_gc_new_with_values (root_window, &gc_values, values_mask);
-  gdk_gc_set_rgb_fg_color (gc, &gc_white);
-  gdk_gc_set_rgb_bg_color (gc, &gc_black);
+  value_mask = GCFunction | GCLineWidth | GCLineStyle |
+               GCFillStyle | GCGraphicsExposures | GCSubwindowMode |
+               GCBackground | GCForeground;
+
+  gc = XCreateGC (display,
+                  gdk_x11_get_default_root_xwindow (),
+                  value_mask,
+                  &gc_values);
 
   /* Change cursor to cross-hair */
   TRACE ("Set the cursor");
+  xhair_cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
+                                             GDK_CROSSHAIR);
 
-  gdk_pointer_grab (root_window, FALSE, mask, NULL,
-                    xhair_cursor, GDK_CURRENT_TIME);
-  gdk_keyboard_grab (root_window, FALSE, GDK_CURRENT_TIME);
+  seat = gdk_display_get_default_seat (gdk_display_get_default ());
+  pointer = gdk_seat_get_pointer (seat);
+  keyboard = gdk_seat_get_keyboard (seat);
+
+  gdk_device_grab (keyboard, root_window,
+                  GDK_OWNERSHIP_NONE, FALSE,
+                  GDK_KEY_PRESS_MASK |
+                  GDK_KEY_RELEASE_MASK,
+                  NULL, GDK_CURRENT_TIME);
+
+  gdk_device_grab (pointer, root_window,
+                   GDK_OWNERSHIP_NONE, FALSE,
+                   GDK_POINTER_MOTION_MASK |
+                   GDK_BUTTON_PRESS_MASK | 
+                   GDK_BUTTON_RELEASE_MASK,
+                   xhair_cursor, GDK_CURRENT_TIME);
 
   /* Initialize the rubber band data */
   TRACE ("Initialize the rubber band data");
-  rbdata.root_window = root_window;
-  rbdata.gc = gc;
+  rbdata.context = &gc;
   rbdata.pressed = FALSE;
   rbdata.cancelled = FALSE;
 
@@ -990,27 +1029,28 @@ static GdkPixbuf
                             (GdkFilterFunc) region_filter_func,
                             &rbdata);
 
-  gdk_pointer_ungrab(GDK_CURRENT_TIME);
-  gdk_keyboard_ungrab (GDK_CURRENT_TIME);
+  gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+  gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
 
   /* Get the screenshot's pixbuf */
   if (G_LIKELY (!rbdata.cancelled))
     {
       TRACE ("Get the pixbuf for the screenshot");
 
+      sleep(delay);
+
       screenshot =
-        gdk_pixbuf_get_from_drawable (NULL, root_window, NULL,
-                                      rbdata.rectangle.x,
-                                      rbdata.rectangle.y,
-                                      0, 0,
-                                      rbdata.rectangle.width,
-                                      rbdata.rectangle.height);
+        gdk_pixbuf_get_from_window (root_window,
+                                    rbdata.rectangle.x,
+                                    rbdata.rectangle.y,
+                                    rbdata.rectangle.width,
+                                    rbdata.rectangle.height);
     }
 
   if (G_LIKELY (gc != NULL))
-    g_object_unref (gc);
+    XFreeGC (display, gc);
 
-  gdk_cursor_unref (xhair_cursor);
+  g_object_unref (xhair_cursor);
 
   return screenshot;
 }
@@ -1030,10 +1070,10 @@ static GdkPixbuf
  *
  * Takes a screenshot with the given options. If @region is FULLSCREEN,
  * the screenshot is taken after @delay seconds. If @region is
- * ACTIVE_WINDOW, a delay of @delay seconds ellapses, then the active
- * window is detected and captured. If @region is SELECT, @delay will
- * be ignored and the user will have to select a portion of the screen
- * with the mouse.
+ * ACTIVE_WINDOW, a delay of @delay seconds elapses, then the active
+ * window is detected and captured. If @region is SELECT, the user will
+ * have to select a portion of the screen with the mouse. Then a delay of
+ * @delay seconds elapses, and a screenshot is taken.
  *
  * @show_mouse is only taken into account when @region is FULLSCREEN
  * or ACTIVE_WINDOW.
@@ -1067,7 +1107,9 @@ GdkPixbuf *screenshooter_take_screenshot (gint     region,
   gdk_window_process_all_updates ();
 
   /* wait for n=delay seconds */
-  if (region != SELECT)
+  if (region == SELECT)
+    delay = 1;
+  else
     sleep (delay);
 
   /* Get the window/desktop we want to screenshot*/
@@ -1099,9 +1141,9 @@ GdkPixbuf *screenshooter_take_screenshot (gint     region,
     {
       TRACE ("Let the user select the region to screenshot");
       if (!gdk_screen_is_composited (screen))
-        screenshot = get_rectangle_screenshot ();
+        screenshot = get_rectangle_screenshot (delay);
       else
-        screenshot = get_rectangle_screenshot_composited ();
+        screenshot = get_rectangle_screenshot_composited (delay);
     }
 
   return screenshot;
