@@ -19,62 +19,67 @@
 
 #include "screenshooter-job-callbacks.h"
 
-/* Create and return a dialog with a throbber and a translated title
+/* Create and return a dialog with a spinner and a translated title
  * will be used during upload jobs
  */
 
 GtkWidget *
-create_throbber_dialog             (const gchar        *title,
+create_spinner_dialog             (const gchar        *title,
                                     GtkWidget         **label)
 {
   GtkWidget *dialog;
   GtkWidget *status_label;
-  GtkWidget *hbox, *throbber;
+  GtkWidget *hbox, *spinner;
   GtkWidget *main_box, *main_alignment;
 
-  dialog = gtk_dialog_new_with_buttons (title,
-                                 NULL,
-                                 GTK_DIALOG_NO_SEPARATOR,
-                                 NULL);
+  dialog = gtk_dialog_new_with_buttons (title, NULL,
+                                        GTK_DIALOG_DESTROY_WITH_PARENT,
+                                        NULL, NULL);
 
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 0);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 0);
   gtk_window_set_deletable (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), "gtk-info");
 
   /* Create the main alignment for the dialog */
-  main_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (main_alignment), 0, 0, 6, 6);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), main_alignment, TRUE, TRUE, 0);
+  main_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (main_alignment, TRUE);
+  gtk_widget_set_vexpand (main_alignment, TRUE);
+  gtk_widget_set_margin_top (main_alignment, 0);
+  gtk_widget_set_margin_bottom (main_alignment, 0);
+  gtk_widget_set_margin_start (main_alignment, 6);
+  gtk_widget_set_margin_end (main_alignment, 6);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), main_alignment, TRUE, TRUE, 0);
 
   /* Create the main box for the dialog */
-  main_box = gtk_vbox_new (FALSE, 10);
+  main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (main_box), 12);
   gtk_container_add (GTK_CONTAINER (main_alignment), main_box);
 
-  /* Top horizontal box for the throbber */
-  hbox= gtk_hbox_new (FALSE, 0);
+  /* Top horizontal box for the spinner */
+  hbox= gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
   gtk_container_add (GTK_CONTAINER (main_box), hbox);
 
-  /* Add the throbber */
-  throbber = katze_throbber_new ();
-  katze_throbber_set_animated (KATZE_THROBBER (throbber), TRUE);
-  gtk_box_pack_end (GTK_BOX (hbox), throbber, FALSE, FALSE, 0);
+  /* Add the spinner */
+  spinner = gtk_spinner_new ();
+  gtk_spinner_start (GTK_SPINNER (spinner));
+  gtk_box_pack_end (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
 
   /* Status label*/
   status_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL (status_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Status</span>"));
-  gtk_misc_set_alignment (GTK_MISC (status_label), 0, 0);
+  gtk_widget_set_halign (status_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (status_label, GTK_ALIGN_START);
   gtk_box_pack_start (GTK_BOX (hbox), status_label, FALSE, FALSE, 0);
 
   /* Information label */
   *label = gtk_label_new ("");
   gtk_container_add (GTK_CONTAINER (main_box), *label);
 
-  gtk_widget_show_all (GTK_DIALOG(dialog)->vbox);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dialog)));
   return dialog;
 }
 
@@ -145,7 +150,7 @@ cb_ask_for_information (ScreenshooterJob *job,
   GtkWidget *dialog;
   GtkWidget *information_label;
   GtkWidget *vbox, *main_alignment;
-  GtkWidget *table;
+  GtkWidget *grid;
   GtkWidget *user_entry, *password_entry, *title_entry, *comment_entry;
   GtkWidget *user_label, *password_label, *title_label, *comment_label;
 
@@ -162,15 +167,15 @@ cb_ask_for_information (ScreenshooterJob *job,
   dialog =
     xfce_titled_dialog_new_with_buttons (_("Details about the screenshot for ZimageZ"),
                                          NULL,
-                                         GTK_DIALOG_NO_SEPARATOR,
-                                         GTK_STOCK_CANCEL,
+                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         "gtk-cancel",
                                          GTK_RESPONSE_CANCEL,
-                                         GTK_STOCK_OK,
+                                         "gtk-ok",
                                          GTK_RESPONSE_OK,
                                          NULL);
 
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG(dialog)->vbox), 12);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 12);
 
   gtk_window_set_icon_name (GTK_WINDOW (dialog), "gtk-info");
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -178,35 +183,38 @@ cb_ask_for_information (ScreenshooterJob *job,
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
   /* Create the main alignment for the dialog */
-  main_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (main_alignment), 6, 0, 12, 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), main_alignment, TRUE, TRUE, 0);
+  main_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (main_alignment, TRUE);
+  gtk_widget_set_vexpand (main_alignment, TRUE);
+  gtk_widget_set_margin_top (main_alignment, 6);
+  gtk_widget_set_margin_bottom (main_alignment, 0);
+  gtk_widget_set_margin_start (main_alignment, 12);
+  gtk_widget_set_margin_end (main_alignment, 12);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), main_alignment, TRUE, TRUE, 0);
 
   /* Create the main box for the dialog */
-  vbox = gtk_vbox_new (FALSE, 10);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_container_add (GTK_CONTAINER (main_alignment), vbox);
 
   /* Create the information label */
   information_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL (information_label), message);
-  gtk_misc_set_alignment (GTK_MISC (information_label), 0, 0);
+  gtk_widget_set_halign (information_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (information_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (vbox), information_label);
 
-  /* Create the layout table */
-  table = gtk_table_new (4, 2, FALSE);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 12);
-  gtk_container_add (GTK_CONTAINER (vbox), table);
+  /* Create the layout grid */
+  grid = gtk_grid_new ();
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
+  gtk_grid_set_row_spacing (GTK_GRID (grid), 12);
+  gtk_container_add (GTK_CONTAINER (vbox), grid);
 
   /* Create the user label */
   user_label = gtk_label_new (_("User:"));
-  gtk_misc_set_alignment (GTK_MISC (user_label), 0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), user_label,
-                    0, 1,
-                    0, 1,
-                    GTK_FILL, GTK_FILL,
-                    0, 0);
+  gtk_widget_set_halign (user_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (user_label, GTK_ALIGN_CENTER);
+  gtk_grid_attach (GTK_GRID (grid), user_label, 0, 0, 1, 1);
 
   /* Create the user entry */
   user_entry = gtk_entry_new ();
@@ -214,48 +222,40 @@ cb_ask_for_information (ScreenshooterJob *job,
                                _("Your Zimagez user name, if you do not have one yet"
                                  " please create one on the Web page linked above"));
   gtk_entry_set_activates_default (GTK_ENTRY (user_entry), TRUE);
-  gtk_table_attach_defaults (GTK_TABLE (table), user_entry, 1, 2, 0, 1);
+  gtk_grid_attach (GTK_GRID (grid), user_entry, 1, 0, 1, 1);
 
   /* Create the password label */
   password_label = gtk_label_new (_("Password:"));
-  gtk_misc_set_alignment (GTK_MISC (password_label), 0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), password_label,
-                    0, 1,
-                    1, 2,
-                    GTK_FILL, GTK_FILL,
-                    0, 0);
+  gtk_widget_set_halign (password_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (password_label, GTK_ALIGN_CENTER);
+  gtk_grid_attach (GTK_GRID (grid), password_label, 0, 1, 1, 1);
 
   /* Create the password entry */
   password_entry = gtk_entry_new ();
   gtk_widget_set_tooltip_text (password_entry, _("The password for the user above"));
   gtk_entry_set_visibility (GTK_ENTRY (password_entry), FALSE);
   gtk_entry_set_activates_default (GTK_ENTRY (password_entry), TRUE);
-  gtk_table_attach_defaults (GTK_TABLE (table), password_entry, 1, 2, 1, 2);
+  gtk_grid_attach (GTK_GRID (grid), password_entry, 1, 1, 1, 1);
 
   /* Create the title label */
   title_label = gtk_label_new (_("Title:"));
-  gtk_misc_set_alignment (GTK_MISC (title_label), 0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), title_label,
-                    0, 1,
-                    2, 3,
-                    GTK_FILL, GTK_FILL,
-                    0, 0);
+  gtk_widget_set_halign (title_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (title_label, GTK_ALIGN_CENTER);
+  gtk_grid_attach (GTK_GRID (grid), title_label, 0, 2, 1, 1);
+
   /* Create the title entry */
   title_entry = gtk_entry_new ();
   gtk_widget_set_tooltip_text (title_entry,
                                _("The title of the screenshot, it will be used when"
                                  " displaying the screenshot on ZimageZ"));
   gtk_entry_set_activates_default (GTK_ENTRY (title_entry), TRUE);
-  gtk_table_attach_defaults (GTK_TABLE (table), title_entry, 1, 2, 2, 3);
+  gtk_grid_attach (GTK_GRID (grid), title_entry, 1, 2, 1, 1);
 
   /* Create the comment label */
   comment_label = gtk_label_new (_("Comment:"));
-  gtk_misc_set_alignment (GTK_MISC (comment_label), 0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), comment_label,
-                    0, 1,
-                    3, 4,
-                    GTK_FILL, GTK_FILL,
-                    0, 0);
+  gtk_widget_set_halign (comment_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (comment_label, GTK_ALIGN_CENTER);
+  gtk_grid_attach (GTK_GRID (grid), comment_label, 0, 3, 1, 1);
 
   /* Create the comment entry */
   comment_entry = gtk_entry_new ();
@@ -263,7 +263,7 @@ cb_ask_for_information (ScreenshooterJob *job,
                                _("A comment on the screenshot, it will be used when"
                                  " displaying the screenshot on ZimageZ"));
   gtk_entry_set_activates_default (GTK_ENTRY (comment_entry), TRUE);
-  gtk_table_attach_defaults (GTK_TABLE (table), comment_entry, 1, 2, 3, 4);
+  gtk_grid_attach (GTK_GRID (grid), comment_entry, 1, 3, 1, 1);
 
   /* Set the values */
   gtk_tree_model_get_iter_first (GTK_TREE_MODEL (liststore), &iter);
@@ -299,7 +299,7 @@ cb_ask_for_information (ScreenshooterJob *job,
     }
   while (gtk_tree_model_iter_next (GTK_TREE_MODEL (liststore), &iter));
 
-  gtk_widget_show_all (GTK_DIALOG(dialog)->vbox);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dialog)));
   response = gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_hide (dialog);
 
@@ -412,24 +412,29 @@ void cb_image_uploaded (ScreenshooterJob  *job,
   dialog =
     xfce_titled_dialog_new_with_buttons (title,
                                          NULL,
-                                         GTK_DIALOG_NO_SEPARATOR,
-                                         GTK_STOCK_CLOSE,
+                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         "gtk-close",
                                          GTK_RESPONSE_CLOSE,
                                          NULL);
 
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 0);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
+  gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 0);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 12);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), "applications-internet");
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
   /* Create the main alignment for the dialog */
-  main_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (main_alignment), 6, 0, 10, 10);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), main_alignment, TRUE, TRUE, 0);
+  main_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (main_alignment, TRUE);
+  gtk_widget_set_vexpand (main_alignment, TRUE);
+  gtk_widget_set_margin_top (main_alignment, 6);
+  gtk_widget_set_margin_bottom (main_alignment, 0);
+  gtk_widget_set_margin_start (main_alignment, 10);
+  gtk_widget_set_margin_end (main_alignment, 10);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), main_alignment, TRUE, TRUE, 0);
 
   /* Create the main box for the dialog */
-  vbox = gtk_vbox_new (FALSE, 10);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_container_add (GTK_CONTAINER (main_alignment), vbox);
 
@@ -438,37 +443,46 @@ void cb_image_uploaded (ScreenshooterJob  *job,
   gtk_label_set_markup (GTK_LABEL (link_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Links</span>"));
-  gtk_misc_set_alignment (GTK_MISC (link_label), 0, 0);
+  gtk_widget_set_halign (link_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (link_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (vbox), link_label);
 
   /* Links alignment */
-  links_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (links_alignment), 0, 0, 12, 0);
+  links_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (links_alignment, TRUE);
+  gtk_widget_set_vexpand (links_alignment, TRUE);
+  gtk_widget_set_margin_top (links_alignment, 0);
+  gtk_widget_set_margin_bottom (links_alignment, 0);
+  gtk_widget_set_margin_start (links_alignment, 12);
+  gtk_widget_set_margin_end (links_alignment, 0);
   gtk_container_add (GTK_CONTAINER (vbox), links_alignment);
 
   /* Links box */
-  links_box = gtk_vbox_new (FALSE, 10);
+  links_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (links_box), 0);
   gtk_container_add (GTK_CONTAINER (links_alignment), links_box);
 
   /* Create the image link */
   image_link = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (image_link), image_markup);
-  gtk_misc_set_alignment (GTK_MISC (image_link), 0, 0);
+  gtk_widget_set_halign (image_link, GTK_ALIGN_START);
+  gtk_widget_set_valign (image_link, GTK_ALIGN_START);
   gtk_widget_set_tooltip_text (image_link, image_url);
   gtk_container_add (GTK_CONTAINER (links_box), image_link);
 
   /* Create the thumbnail link */
   thumbnail_link = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (thumbnail_link), thumbnail_markup);
-  gtk_misc_set_alignment (GTK_MISC (thumbnail_link), 0, 0);
+  gtk_widget_set_halign (thumbnail_link, GTK_ALIGN_START);
+  gtk_widget_set_valign (thumbnail_link, GTK_ALIGN_START);
   gtk_widget_set_tooltip_text (thumbnail_link, thumbnail_url);
   gtk_container_add (GTK_CONTAINER (links_box), thumbnail_link);
 
   /* Create the small thumbnail link */
   small_thumbnail_link = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (small_thumbnail_link), small_thumbnail_markup);
-  gtk_misc_set_alignment (GTK_MISC (small_thumbnail_link), 0, 0);
+  gtk_widget_set_halign (small_thumbnail_link, GTK_ALIGN_START);
+  gtk_widget_set_valign (small_thumbnail_link, GTK_ALIGN_START);
   gtk_widget_set_tooltip_text (small_thumbnail_link, small_thumbnail_url);
   gtk_container_add (GTK_CONTAINER (links_box), small_thumbnail_link);
 
@@ -477,22 +491,29 @@ void cb_image_uploaded (ScreenshooterJob  *job,
   gtk_label_set_markup (GTK_LABEL (example_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Code for a thumbnail pointing to the full size image</span>"));
-  gtk_misc_set_alignment (GTK_MISC (example_label), 0, 0);
+  gtk_widget_set_halign (example_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (example_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (vbox), example_label);
 
   /* Code alignment */
-  code_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (code_alignment), 0, 0, 12, 0);
+  code_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (code_alignment, TRUE);
+  gtk_widget_set_vexpand (code_alignment, TRUE);
+  gtk_widget_set_margin_top (code_alignment, 0);
+  gtk_widget_set_margin_bottom (code_alignment, 0);
+  gtk_widget_set_margin_start (code_alignment, 12);
+  gtk_widget_set_margin_end (code_alignment, 0);
   gtk_container_add (GTK_CONTAINER (vbox), code_alignment);
 
   /* Links box */
-  code_box = gtk_vbox_new (FALSE, 10);
+  code_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (code_box), 0);
   gtk_container_add (GTK_CONTAINER (code_alignment), code_box);
 
   /* HTML title */
   html_label = gtk_label_new (_("HTML"));
-  gtk_misc_set_alignment (GTK_MISC (html_label), 0, 0);
+  gtk_widget_set_halign (html_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (html_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (code_box), html_label);
 
   /* HTML frame */
@@ -513,7 +534,8 @@ void cb_image_uploaded (ScreenshooterJob  *job,
 
   /* BB title */
   bb_label = gtk_label_new (_("BBCode for forums"));
-  gtk_misc_set_alignment (GTK_MISC (bb_label), 0, 0);
+  gtk_widget_set_halign (bb_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (bb_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (code_box), bb_label);
 
   /* BB frame */
@@ -535,7 +557,7 @@ void cb_image_uploaded (ScreenshooterJob  *job,
   gtk_container_add (GTK_CONTAINER (bb_frame), bb_code_view);
 
   /* Show the dialog and run it */
-  gtk_widget_show_all (GTK_DIALOG(dialog)->vbox);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dialog)));
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 
