@@ -114,30 +114,17 @@ Returns TRUE if succesful.
 static gboolean
 cb_set_size (XfcePanelPlugin *plugin, int size, PluginData *pd)
 {
-  GdkPixbuf *pb;
+  gint icon_size;
 
-#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
   /* reduce the size of the plugin to a single row */
   size /= xfce_panel_plugin_get_nrows (plugin);
-#endif
-
-  int width = size - 2 - 2 * MAX (pd->button->style->xthickness,
-                                    pd->button->style->ythickness);
-
-  TRACE ("Get the icon from the theme");
-  pb = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                 SCREENSHOT_ICON_NAME,
-                                 width,
-                                 GTK_ICON_LOOKUP_FORCE_SIZE,
-                                 NULL);
-
-  TRACE ("Set the new icon");
-  gtk_image_set_from_pixbuf (GTK_IMAGE (pd->image), pb);
-  g_object_unref (pb);
 
   TRACE ("Request size for the plugin");
   gtk_widget_set_size_request (GTK_WIDGET (plugin), size, size);
 
+  icon_size = xfce_panel_plugin_get_icon_size (plugin);
+  gtk_image_set_pixel_size (GTK_IMAGE (pd->image), icon_size);
+
   return TRUE;
 }
 
@@ -265,20 +252,22 @@ screenshooter_plugin_write_rc_file (XfcePanelPlugin *plugin, PluginData *pd)
 static void
 cb_dialog_response (GtkWidget *dlg, int response, PluginData *pd)
 {
+  g_object_set_data (G_OBJECT (pd->plugin), "dialog", NULL);
+  gtk_widget_destroy (dlg);
+
+  /* Unblock the menu */
+  xfce_panel_plugin_unblock_menu (pd->plugin);
+
   if (response == GTK_RESPONSE_OK)
     {
-      g_object_set_data (G_OBJECT (pd->plugin), "dialog", NULL);
-      gtk_widget_destroy (dlg);
-
       /* Update tooltips according to the chosen option */
       set_panel_button_tooltip (pd);
 
-      /* Unblock the menu and save options */
-      xfce_panel_plugin_unblock_menu (pd->plugin);
+      /* Save options */
       screenshooter_plugin_write_rc_file (pd->plugin, pd);
     }
   else if (response == GTK_RESPONSE_HELP)
-    screenshooter_open_help ();
+    screenshooter_open_help (NULL);
 }
 
 
@@ -341,16 +330,13 @@ screenshooter_plugin_construct (XfcePanelPlugin *plugin)
   PluginData *pd = g_new0 (PluginData, 1);
   ScreenshotData *sd = g_new0 (ScreenshotData, 1);
   GFile *default_save_dir;
-
-  g_thread_init (NULL);
+  gint icon_size;
 
   pd->sd = sd;
   pd->plugin = plugin;
 
-#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
   /* make the plugin fit a single row */
   xfce_panel_plugin_set_small (plugin, TRUE);
-#endif
 
   TRACE ("Initialize the text domain");
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
@@ -381,7 +367,8 @@ screenshooter_plugin_construct (XfcePanelPlugin *plugin)
   TRACE ("Create the panel button");
   pd->button = xfce_create_panel_button ();
 
-  pd->image = gtk_image_new ();
+  icon_size = xfce_panel_plugin_get_icon_size (plugin);
+  pd->image = gtk_image_new_from_icon_name (SCREENSHOT_ICON_NAME, icon_size);
 
   gtk_container_add (GTK_CONTAINER (pd->button), GTK_WIDGET (pd->image));
 
@@ -393,6 +380,7 @@ screenshooter_plugin_construct (XfcePanelPlugin *plugin)
   gtk_container_add (GTK_CONTAINER (plugin), pd->button);
   xfce_panel_plugin_add_action_widget (plugin, pd->button);
   gtk_widget_show_all (pd->button);
+  gtk_widget_add_events (pd->button, GDK_SCROLL_MASK);
 
   /* Set the callbacks */
   g_signal_connect (pd->button, "clicked",
